﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rssgs_iq_modulated_signal
{
    public partial class rssgs_generating_iq_modulated_signal_example : Form
    {
        private rssgs m_instrument = null;

        public rssgs_generating_iq_modulated_signal_example()
        {
            InitializeComponent();            
        }

        private void EnableButtons(bool enable)
        {            
            SettingsGB.Enabled = enable;
            IQSettingsGB.Enabled = enable;

            if (m_instrument == null)
                enable = false;
            else
                enable = true;
            
            ResourceGB.Enabled = !enable;
            ConnectBtn.Enabled = !enable;
            ApplyBtn.Enabled = enable;
            GainImbaDispl.Enabled = false;
        }

        private void ConnectBtn_Click(object sender, EventArgs e)
        {
            try
            {
                /* lock GUI */
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
                EnableButtons(false);

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rssgs(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();                
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);

                EnableButtons(false);
            }
            finally
            {
                /* unlock GUI */
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
                EnableButtons(true);
            }

        }

        private void ApplyBtn_Click(object sender, EventArgs e)
        {
            double gainImbaRead;

            try
            {
                EnableButtons(false);

                m_instrument.SetOperationMode(rssgsConstants.OperationModeNormal);

                m_instrument.SetFrequencyAndLevel(Convert.ToDouble(RFFreq.Value), Convert.ToDouble(Level.Value));

                m_instrument.SetROSCSource(rssgsConstants.SourceInt);

                m_instrument.SetFrequencyLocalOscillatorSource(rssgsConstants.SourceInt);

                m_instrument.SetIQImpairmentsIOffset(Convert.ToDouble(IOffset.Value));

                m_instrument.SetIQImpairmentsQOffset(Convert.ToDouble(QOffset.Value));

                m_instrument.SetIQImpairmentsGainImbalance(Convert.ToDouble(GainImba.Value));

                m_instrument.GetIQImpairmentsGainImbalance(out gainImbaRead);
                GainImbaDispl.Text = Convert.ToString(gainImbaRead);

                m_instrument.SetIQImpairmentsQuadratureOffset(Convert.ToDouble(QuadOffset.Value));

                m_instrument.SetIQWideband(true);

                m_instrument.SetIQImpairmentsState(true);

                m_instrument.SetRFState(RFState.Checked);
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);

                EnableButtons(false);
            }
            finally
            {
                /* unlock GUI */
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
                EnableButtons(true);
            }
        }


        private void ExitBtn_Click(object sender, EventArgs e)
        {
            Close();
        }
    }
}
